pub struct NodeDescriptor {
pub id: NodeId,
pub descriptor: String,
pub configuration: Option<Configuration>,
}Expand description
Describes an node of the graph
id : PrintSink
descriptor: file://./target/release/counter_source.yaml
configuration:
start: 10Fields
id: NodeIddescriptor: Stringconfiguration: Option<Configuration>Implementations
Sourceimpl NodeDescriptor
impl NodeDescriptor
Sourcepub fn from_yaml(data: &str) -> Result<Self>
pub fn from_yaml(data: &str) -> Result<Self>
Creates a new NodeDescriptor from its YAML representation.
Errors
A variant error is returned if deserialization fails.
Sourcepub fn from_json(data: &str) -> Result<Self>
pub fn from_json(data: &str) -> Result<Self>
Creates a new NodeDescriptor from its JSON representation.
Errors
A variant error is returned if deserialization fails.
Sourcepub fn to_json(&self) -> Result<String>
pub fn to_json(&self) -> Result<String>
Returns the JSON representation of the NodeDescriptor.
Errors
A variant error is returned if serialization fails.
Sourcepub fn to_yaml(&self) -> Result<String>
pub fn to_yaml(&self) -> Result<String>
Returns the YAML representation of the NodeDescriptor.
Errors
A variant error is returned if serialization fails.
Sourcepub async fn flatten(
self,
id: NodeId,
links: &mut Vec<LinkDescriptor>,
global_configuration: Option<Configuration>,
ancestors: &mut Vec<String>,
) -> Result<Vec<OperatorDescriptor>>
pub async fn flatten( self, id: NodeId, links: &mut Vec<LinkDescriptor>, global_configuration: Option<Configuration>, ancestors: &mut Vec<String>, ) -> Result<Vec<OperatorDescriptor>>
Flattens the NodeDescriptor by loading all the composite operators
Errors
A variant error is returned if loading operators fails. Or if the node does not contains an operator
Sourcepub async fn load_source(
self,
global_configuration: Option<Configuration>,
) -> Result<SourceDescriptor>
pub async fn load_source( self, global_configuration: Option<Configuration>, ) -> Result<SourceDescriptor>
Loads the source from the NodeDescriptor
Errors
A variant error is returned if loading source fails. Or if the node does not contains an source
Sourcepub async fn load_sink(
self,
global_configuration: Option<Configuration>,
) -> Result<SinkDescriptor>
pub async fn load_sink( self, global_configuration: Option<Configuration>, ) -> Result<SinkDescriptor>
Loads the sink from the NodeDescriptor
Errors
A variant error is returned if loading sink fails. Or if the node does not contains an sink