Loader

Struct Loader 

pub struct Loader { /* private fields */ }
The dynamic library loader. Before loading it verifies if the versions are compatible and if the symbols are presents. It loads the files in different way depending on the operating system. In particular the scope of the symbols is different between Unix and Windows. In Unix system the symbols are loaded with the flags:

  • RTLD_NOW load all the symbols when loading the library.
  • RTLD_LOCAL keep all the symbols local.

Implementations

Source

impl Loader

pub fn new(config: LoaderConfig) -> Self

Creates a new Loader with the given config.