Module node

Module node 

Type Aliases

OperatorFn
OperatorFn is the only signature we accept to construct an Operator.
SinkFn
SinkFn is the only signature we accept to construct a Sink.
SourceFn
SourceFn is the only signature we accept to construct a Source.