DataFlow

Struct DataFlow 

pub struct DataFlow { /* private fields */ }
DataFlow is an intermediate structure which primary purpose is to store the loaded libraries.

This intermediate structure is needed to create data flows programmatically. It is mostly used internally to assess the performance of Zenoh-Flow.

End users should not use it directly: no verifications to ensure the validity of the data flow are performed at this step or in the next ones.

Implementations

Source

impl DataFlow

pub fn new(name: impl AsRef<str>, context: RuntimeContext) -> Self

Create a new empty DataFlow named name with the provided RuntimeContext.

Unless you know very well what you are doing, you should not use this function.

This function is the entry point to create a data flow programmatically. It should not be called by end users.

pub fn add_source(&mut self, record: SourceRecord, constructor: SourceFn)

Add a Source to the DataFlow.

Unless you know very well what you are doing, you should not use this method.

If the Source is not correctly connected to downstream nodes, its data will never be received.

pub fn add_operator(&mut self, record: OperatorRecord, constructor: OperatorFn)

Add an Operator to the DataFlow.

Unless you know very well what you are doing, you should not use this method.

If the Operator is not correctly connected to upstream and downstream nodes, it will never receive, process and emit data.

pub fn add_sink(&mut self, record: SinkRecord, constructor: SinkFn)

Add a Sink to the DataFlow.

Unless you know very well what you are doing, you should not use this method.

If the Sink is not correctly connected to upstream nodes, it will never receive data.

Add a Link to the DataFlow.

Unless you know very well what you are doing, you should not use this method.

If the OutputDescriptor and InputDescriptor are incorrect, Zenoh-Flow will error out at runtime.

pub fn try_new( record: DataFlowRecord, context: RuntimeContext, ) -> ZFResult<Self>

Given a DataFlowRecord, create the corresponding DataFlow by dynamically loading the shared libraries.

Error

Failures can happen when trying to load node factories.