pub enum DaemonInterfaceInternalRequest {
Prepare {
instance_id: Uuid,
},
Clean {
instance_id: Uuid,
},
Start {
instance_id: Uuid,
},
StartSources {
instance_id: Uuid,
},
Stop {
instance_id: Uuid,
},
StopSources {
instance_id: Uuid,
},
NotifyRuntime {
instance_id: Uuid,
runtime: String,
message: ControlMessage,
},
CheckOperatorCompatibility {
operator: OperatorDescriptor,
},
CheckSourceCompatibility {
source: SourceDescriptor,
},
CheckSinkCompatibility {
sink: SinkDescriptor,
},
}Expand description
The request sent over the wire from the client to the server.
Variants
Prepare
Clean
Start
StartSources
Stop
StopSources
NotifyRuntime
CheckOperatorCompatibility
Fields

operator: OperatorDescriptorCheckSourceCompatibility
Fields

source: SourceDescriptorCheckSinkCompatibility
Fields

sink: SinkDescriptorTrait Implementations
Sourceimpl Clone for DaemonInterfaceInternalRequest
impl Clone for DaemonInterfaceInternalRequest
Sourcefn clone(&self) -> DaemonInterfaceInternalRequest
fn clone(&self) -> DaemonInterfaceInternalRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for DaemonInterfaceInternalRequest
impl<'de> Deserialize<'de> for DaemonInterfaceInternalRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<S> ZServe<DaemonInterfaceInternalRequest> for ServeDaemonInterfaceInternal<S>where
S: DaemonInterfaceInternal + Send + 'static,
impl<S> ZServe<DaemonInterfaceInternalRequest> for ServeDaemonInterfaceInternal<S>where
S: DaemonInterfaceInternal + Send + 'static,
Sourcetype Resp = DaemonInterfaceInternalResponse
type Resp = DaemonInterfaceInternalResponse
Type of the response
fn instance_uuid(&self) -> ZenohId
Sourcefn connect(
&self,
) -> Pin<Box<dyn Future<Output = ZRPCResult<(AbortHandle, JoinHandle<Result<ZRPCResult<()>, Aborted>>)>> + '_>>
fn connect( &self, ) -> Pin<Box<dyn Future<Output = ZRPCResult<(AbortHandle, JoinHandle<Result<ZRPCResult<()>, Aborted>>)>> + '_>>
Connects to Zenoh, do nothing in this case, state is HALTED
Sourcefn initialize(&self) -> Pin<Box<dyn Future<Output = ZRPCResult<()>> + '_>>
fn initialize(&self) -> Pin<Box<dyn Future<Output = ZRPCResult<()>> + '_>>
Authenticates to Zenoh, state changes to INITIALIZING
fn register(&self) -> Pin<Box<dyn Future<Output = ZRPCResult<()>> + '_>>
Sourcefn start(
&self,
) -> Pin<Box<dyn Future<Output = ZRPCResult<(AbortHandle, JoinHandle<Result<ZRPCResult<()>, Aborted>>)>> + '_>>
fn start( &self, ) -> Pin<Box<dyn Future<Output = ZRPCResult<(AbortHandle, JoinHandle<Result<ZRPCResult<()>, Aborted>>)>> + '_>>
State changes to SERVING, calls serve on a task::spawn, returns a stop sender and the serve task handle
Sourcefn run(&self) -> Pin<Box<dyn Future<Output = ZRPCResult<()>> + '_>>
fn run(&self) -> Pin<Box<dyn Future<Output = ZRPCResult<()>> + '_>>
The actual run loop serving the queriable
Sourcefn serve(
&self,
barrier: Arc<Barrier>,
) -> Pin<Box<dyn Future<Output = ZRPCResult<()>> + '_>>
fn serve( &self, barrier: Arc<Barrier>, ) -> Pin<Box<dyn Future<Output = ZRPCResult<()>> + '_>>
Starts serving all requests
Sourcefn stop(
&self,
stop: AbortHandle,
) -> Pin<Box<dyn Future<Output = ZRPCResult<()>> + '_>>
fn stop( &self, stop: AbortHandle, ) -> Pin<Box<dyn Future<Output = ZRPCResult<()>> + '_>>
State changes to REGISTERED, will stop serve/work
fn unregister(&self) -> Pin<Box<dyn Future<Output = ZRPCResult<()>> + '_>>
Sourcefn disconnect(
&self,
stop: AbortHandle,
) -> Pin<Box<dyn Future<Output = ZRPCResult<()>> + '_>>
fn disconnect( &self, stop: AbortHandle, ) -> Pin<Box<dyn Future<Output = ZRPCResult<()>> + '_>>
removes state from Zenoh