DaemonInterfaceClient

Struct DaemonInterfaceClient 

pub struct DaemonInterfaceClient<C = ZClientChannel<DaemonInterfaceRequest, DaemonInterfaceResponse>> { /* private fields */ }

Implementations

Source

impl DaemonInterfaceClient

pub fn new(z: Arc<Session>, instance_id: ZenohId) -> DaemonInterfaceClient

pub fn get_server_uuid(&self) -> ZenohId

pub fn find_servers( z: Arc<Session>, ) -> impl Future<Output = ZRPCResult<Vec<ZenohId>>> + 'static

pub fn find_servers_info( z: Arc<Session>, ) -> impl Future<Output = ZRPCResult<Vec<ComponentState>>> + 'static

pub fn find_local_servers( z: Arc<Session>, ) -> impl Future<Output = ZRPCResult<Vec<ZenohId>>> + 'static

Source

impl DaemonInterfaceClient

pub fn verify_server(&self) -> impl Future<Output = ZRPCResult<bool>> + '_

pub fn create_instance( &self, flow: FlattenDataFlowDescriptor, ) -> impl Future<Output = ZRPCResult<DaemonResult<Uuid>>> + '_

Creates an instance of the given FlattenDataFlowDescriptor1.

This function:

  1. Generates the instance Uuid
  2. Maps the flow into the infrastructure
  3. Creates the associated record
  4. Stores the record in Zenoh
  5. Prepares all the involved runtimes to host the data flow instance

Returns the Uuid associated with the instance.

Errors

An error variant is returned in case of:

  • error on zenoh-rpc
  • unable to map
  • unable to prepare nodes

  1. When the registry will be in place it will take the Flow identifier as parameter 

pub fn delete_instance( &self, instance_id: Uuid, ) -> impl Future<Output = ZRPCResult<DaemonResult<DataFlowRecord>>> + '_

Deletes the given instance.

This function:

  1. Cleans the instance nodes from all the involved runtimes.
  2. Deletes the record from zenoh
Errors

An error variant is returned in case of:

  • error on zenoh-rpc
  • instance not stopped
  • unable to clean
  • zenoh error
pub fn instantiate( &self, flow: FlattenDataFlowDescriptor, ) -> impl Future<Output = ZRPCResult<DaemonResult<Uuid>>> + '_

Instantiates the given FlattenDataFlowDescriptor1.

The instance contains an Uuid that identifies it uniquely. The actual instantiation process runs asynchronously in the runtime.

Returns the Uuid associated with the instance.

It is equivalent to calling create_instance and then start_instance.

Errors

An error variant is returned in case of:

  • error on zenoh-rpc
  • unable to instantiate

  1. When the registry will be in place it will take the Flow identifier as parameter. 

pub fn teardown( &self, instance_id: Uuid, ) -> impl Future<Output = ZRPCResult<DaemonResult<DataFlowRecord>>> + '_

Sends a teardown request for the given instance identified by the Uuid.

Note that the request is asynchronous, the runtime that receives the request will return immediately, but the teardown process will run asynchronously in the runtime.

It is equivalent to calling stop_instance and then delete_instance.

Errors

An error variant is returned in case of:

  • error on zenoh-rpc
  • unable to teardown
  • instance not found
pub fn start_instance( &self, instance_id: Uuid, ) -> impl Future<Output = ZRPCResult<DaemonResult<()>>> + '_

Starts the instance on all involved nodes.

It first starts all the nodes and then the sources.

Errors

An error variant is returned in case of:

  • error on zenoh-rpc
  • instance not found
  • instance already started
pub fn stop_instance( &self, instance_id: Uuid, ) -> impl Future<Output = ZRPCResult<DaemonResult<DataFlowRecord>>> + '_

Stops the instance on all involved nodes.

It first stops the sources then the other nodes.

Errors

An error variant is returned in case of:

  • error on zenoh-rpc
  • unable to clean
pub fn start_node( &self, instance_id: Uuid, node: String, ) -> impl Future<Output = ZRPCResult<DaemonResult<()>>> + '_

Starts the given graph node for the given instance. A graph node can be a source, a sink, a connector, or an operator.

Errors

An error variant is returned in case of:

  • error on zenoh-rpc
  • record not found
  • node already started
  • node not found
pub fn stop_node( &self, instance_id: Uuid, node: String, ) -> impl Future<Output = ZRPCResult<DaemonResult<()>>> + '_

Stops the given graph node from the given instance. A graph node can be a source, a sink, a connector, or an operator.

Errors

An error variant is returned in case of:

  • error on zenoh-rpc
  • instance not found
  • node not found
  • node already stopped