DaemonInterfaceInternalClient

Struct DaemonInterfaceInternalClient 

pub struct DaemonInterfaceInternalClient<C = ZClientChannel<DaemonInterfaceInternalRequest, DaemonInterfaceInternalResponse>> { /* private fields */ }

Implementations

Source

impl DaemonInterfaceInternalClient

pub fn new( z: Arc<Session>, instance_id: ZenohId, ) -> DaemonInterfaceInternalClient

pub fn get_server_uuid(&self) -> ZenohId

pub fn find_servers( z: Arc<Session>, ) -> impl Future<Output = ZRPCResult<Vec<ZenohId>>> + 'static

pub fn find_servers_info( z: Arc<Session>, ) -> impl Future<Output = ZRPCResult<Vec<ComponentState>>> + 'static

pub fn find_local_servers( z: Arc<Session>, ) -> impl Future<Output = ZRPCResult<Vec<ZenohId>>> + 'static

Source

impl DaemonInterfaceInternalClient

pub fn verify_server(&self) -> impl Future<Output = ZRPCResult<bool>> + '_

pub fn prepare( &self, instance_id: Uuid, ) -> impl Future<Output = ZRPCResult<DaemonResult<DataFlowRecord>>> + '_

Prepares the runtime host the instance identified by the Uuid.

Preparing a runtime means, fetch the operators/source/sinks libraries, create the needed structures in memory, the links. Once everything is prepared the runtime should return the DataFlowRecord

Errors

An error variant is returned in case of:

  • error on zenoh-rpc
  • unable to prepare
pub fn clean( &self, instance_id: Uuid, ) -> impl Future<Output = ZRPCResult<DaemonResult<DataFlowRecord>>> + '_

Cleans the “remains” of the given instance: unload the libraries, drop data structures and destroy links.

Errors

An error variant is returned in case of:

  • error on zenoh-rpc
  • unable to clean
pub fn start( &self, instance_id: Uuid, ) -> impl Future<Output = ZRPCResult<DaemonResult<()>>> + '_

Starts the sinks, connectors, and operators for the given instance.

Errors

An error variant is returned in case of:

  • error on zenoh-rpc
  • instance not found
  • instance already started
pub fn start_sources( &self, instance_id: Uuid, ) -> impl Future<Output = ZRPCResult<DaemonResult<()>>> + '_

Starts the sources for the given instance. Note that this should be called only after the start(instance) has returned successfully otherwise data may be lost.

Errors

An error variant is returned in case of:

  • error on zenoh-rpc
  • instance not found
  • sources already started
pub fn stop( &self, instance_id: Uuid, ) -> impl Future<Output = ZRPCResult<DaemonResult<()>>> + '_

Stops the sinks, connectors, and operators for the given instance.

Note that this should be called after the stop_sources(instance) has returned successfully otherwise data may be lost.

Errors

An error variant is returned in case of:

  • error on zenoh-rpc
  • instance not found
  • instance already stopped
pub fn stop_sources( &self, instance_id: Uuid, ) -> impl Future<Output = ZRPCResult<DaemonResult<()>>> + '_

Stops the sources for the given instance.

Errors

An error variant is returned in case of:

  • error on zenoh-rpc
  • instance not found
  • sources already stopped
pub fn notify_runtime( &self, instance_id: Uuid, runtime: String, message: ControlMessage, ) -> impl Future<Output = ZRPCResult<DaemonResult<()>>> + '_

Sends the message to node for the given instance.

This is useful for sending out-of-band notification to a node (eg. in the case of deadline miss notification).

Errors

An error variant is returned in case of:

  • error on zenoh-rpc
  • instance not found
pub fn check_operator_compatibility( &self, operator: OperatorDescriptor, ) -> impl Future<Output = ZRPCResult<DaemonResult<bool>>> + '_

Checks the compatibility for the given operator.

Compatibility is based on tags and some machine characteristics (eg. CPU architecture, OS).

Errors

An error variant is returned in case of:

  • error on zenoh-rpc
pub fn check_source_compatibility( &self, source: SourceDescriptor, ) -> impl Future<Output = ZRPCResult<DaemonResult<bool>>> + '_

Checks the compatibility for the given source.

Compatibility is based on tags and some machine characteristics (eg. CPU architecture, OS)

Errors

An error variant is returned in case of:

  • error on zenoh-rpc
pub fn check_sink_compatibility( &self, sink: SinkDescriptor, ) -> impl Future<Output = ZRPCResult<DaemonResult<bool>>> + '_

Checks the compatibility for the given sink.

Compatibility is based on tags and some machine characteristics (eg. CPU architecture, OS)

Errors

An error variant is returned in case of:

  • error on zenoh-rpc