pub enum LinkMessage {
Data(DataMessage),
Watermark(Timestamp),
}Expand description
The Zenoh-Flow message that is sent across Link and across Zenoh.
It contains either a DataMessage or a Timestamp,
in such case the LinkMessage variant is Watermark.
Variants
Data(DataMessage)
Watermark(Timestamp)
Implementations
Sourceimpl LinkMessage
impl LinkMessage
Sourcepub fn from_payload(output: Payload, timestamp: Timestamp) -> Self
pub fn from_payload(output: Payload, timestamp: Timestamp) -> Self
Creates a LinkMessage::Data from a Payload.
Sourcepub fn serialize_bincode_into(
&self,
message_buffer: &mut Vec<u8>,
payload_buffer: &mut Vec<u8>,
) -> Result<()>
pub fn serialize_bincode_into( &self, message_buffer: &mut Vec<u8>, payload_buffer: &mut Vec<u8>, ) -> Result<()>
Serializes the LinkMessage using bincode into the given buffer.
The inner_buffer is used to serialize (if need be) the Payload contained inside the
LinkMessage.
Performance
The provided buffer and inner_buffer are reused and cleared between calls, so once their
capacity stabilizes no (re)allocation is performed.
Errors
An error variant is returned in case of:
- fails to serialize
Sourcepub fn serialize_bincode_into_shm(
&self,
shm_buffer: &mut [u8],
payload_buffer: &mut Vec<u8>,
) -> Result<()>
pub fn serialize_bincode_into_shm( &self, shm_buffer: &mut [u8], payload_buffer: &mut Vec<u8>, ) -> Result<()>
Serializes the LinkMessage using bincode into the given shm_buffer shared memory
buffer.
The inner_buffer is used to serialize (if need be) the Payload contained inside the
LinkMessage.
Performance
The provided inner_buffer is reused and cleared between calls, so once its capacity
stabilizes no (re)allocation is performed.
Errors
An error variant is returned in case of:
- fails to serialize
- there is not enough space in the slice
Sourcepub fn get_timestamp(&self) -> Timestamp
pub fn get_timestamp(&self) -> Timestamp
Returns the Timestamp associated with the message.