DataMessage

Struct DataMessage 

pub struct DataMessage { /* private fields */ }
Zenoh-Flow data message.

It contains the actual data, the timestamp associated, the end to end deadline, the end to end deadline misses and loop contexts.

Implementations

Source

impl DataMessage

pub fn new_serialized(data: Vec<u8>, timestamp: Timestamp) -> Self

Creates a new message from serialized data.

This is used when the message is coming from Zenoh or from a non-rust node.

pub fn get_timestamp(&self) -> &Timestamp

Return the Timestamp associated with this DataMessage.

Methods from Deref<Target = Payload>

pub fn try_as_bytes(&self) -> Result<Arc<Vec<u8>>>

Return an Arc containing the bytes representation of the Payload.

Performance

This method will only serialize (and thus allocate) the Payload if it is typed. Otherwise the Arc is cloned.