pub struct Loader { /* private fields */ }Expand description
The dynamic library loader. Before loading it verifies if the versions are compatible and if the symbols are presents. It loads the files in different way depending on the operating system. In particular the scope of the symbols is different between Unix and Windows. In Unix system the symbols are loaded with the flags:
RTLD_NOWload all the symbols when loading the library.RTLD_LOCALkeep all the symbols local.
Implementations