Module node
zenoh_
flow
0.5.0-alpha.4
Module node
Module Items
Type Aliases
In zenoh_
flow::
runtime::
dataflow
zenoh_flow
::
runtime
::
dataflow
Module
node
Type Aliases

Operator
Fn
OperatorFn
is the only signature we accept to construct an
Operator
.
SinkFn
SinkFn
is the only signature we accept to construct a
Sink
.
Fn
SourceFn
is the only signature we accept to construct a
.