pub struct DataMessage { /* private fields */ }Expand description
Zenoh-Flow data message.
It contains the actual data, the timestamp associated, the end to end deadline, the end to end deadline misses and loop contexts.
Implementations
Sourceimpl DataMessage
impl DataMessage
Sourcepub fn new_serialized(data: Vec<u8>, timestamp: Timestamp) -> Self
pub fn new_serialized(data: Vec<u8>, timestamp: Timestamp) -> Self
Creates a new message from serialized data.
This is used when the message is coming from Zenoh or from a non-rust node.
Sourcepub fn get_timestamp(&self) -> &Timestamp
pub fn get_timestamp(&self) -> &Timestamp
Return the Timestamp associated with this DataMessage.